package com.application;

import javafx.application.Application;

import javafx.scene.chart.LineChart;

import javafx.scene.control.ToggleButton;
import javafx.scene.control.ToggleGroup;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.layout.*;
import javafx.scene.Scene;
import javafx.stage.Stage;


import javafx.scene.chart.CategoryAxis;

import javafx.scene.chart.NumberAxis;
import javafx.scene.chart.XYChart;


import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Objects;

/**
 * This class launches the application
 *
 * @author Eilert Tunheim, Karin Pettersen, Mads Arnesen
 * @version 1.0.0
 */
public class Main extends Application {

    private BorderPane topBar;
    private HBox menuBar;
    private HBox logoBar;
    private VBox sideBar;
    private LineChart lineChart;

    /**
     * Starts the application
     * @param args
     * @throws IOException
     */
    public static void main(String[] args) throws IOException {
        launch(args);
    }

    /**
     * Initializes the application with all the different panes.
     *
     * @throws Exception Exception in super.
     */
    @Override
    public void init() throws Exception {
        super.init();

        // Initializing variables
        this.topBar = new BorderPane();
        this.menuBar = new HBox();
        this.logoBar = new HBox();
        this.sideBar = new VBox();
    }

    /**
     * Sets the primaryStage and sets the scene for the window.
     * @param primaryStage
     * @throws Exception
     */
    @Override
    public void start(Stage primaryStage) throws Exception {

        // Create panes for root
        BorderPane root = new BorderPane();
        this.menuBar = createMenuBar();
        this.logoBar = createLogoBar();
        this.lineChart = createLineChart();

        // Sets alignment for the topBar
        this.topBar.setTop(menuBar);
        this.topBar.setCenter(logoBar);

        this.sideBar.setMinWidth(300);

        //Set id for panes
        root.setId("root");
        this.menuBar.setId("menuBar");

        // Sets alignment for the panes to the parent root
        root.setTop(this.topBar);
        root.setLeft(this.sideBar);
        root.setCenter(this.lineChart);


        // Sets the scene and defines boundaries
        //Scene scene = new Scene(root, 1200, 600);
        Scene scene = new Scene(root, 1200, 600);
        scene.getStylesheets().add(Objects.requireNonNull(getClass().getResource("/com.application/styleSheet.css")).toExternalForm());

        primaryStage.setTitle("Moelven Drying Application");
        //primaryStage.setMaximized(true);
        primaryStage.setMinHeight(600);
        primaryStage.setMinWidth(1200);
        primaryStage.setScene(scene);
        primaryStage.show();
    }

    /**
     * Creates the menubar with buttons.
     * Defines each action when button is clicked.
     *
     * @return MenuBar as a HBox
     */
    private HBox createMenuBar() {
        // Creating buttons for menubar
        ToggleGroup btnMenuGroup = new ToggleGroup();
        ToggleButton btnMenuHome = new ToggleButton("Home");
        ToggleButton btnMenuInput = new ToggleButton("Input");
        ToggleButton btnMenuFinish = new ToggleButton("Finish");
        ToggleButton btnMenuHelp = new ToggleButton("Help");


        // Set the buttons toggleable
        btnMenuHome.setToggleGroup(btnMenuGroup);
        btnMenuInput.setToggleGroup(btnMenuGroup);
        btnMenuFinish.setToggleGroup(btnMenuGroup);
        btnMenuHelp.setToggleGroup(btnMenuGroup);

        // Set the home button as default selected
        btnMenuHome.setSelected(true);

        //Make sure always one button is selected
        btnMenuGroup.selectedToggleProperty().addListener((obsVal, oldVal, newVal) -> {
            if (newVal == null)
                oldVal.setSelected(true);
        });

        /*
        btnMenuMetaImage.setOnAction(e -> featurePane.loadMetaImage());
        btnMenuImport.setOnAction(e -> featurePane.loadImport());
        btnMenuCreate.setOnAction(e -> featurePane.loadCreate());
        btnMenuSearch.setOnAction(e -> featurePane.loadSearch());
         */

        menuBar.getChildren().addAll(btnMenuHome, btnMenuInput, btnMenuFinish, btnMenuHelp);
        return menuBar;
    }



    private HBox createLogoBar() throws FileNotFoundException {
        //Creating an image
        Image moelvenLogoM = new Image(new FileInputStream("src/main/resources/com.application/GUI/moelven_logo_m.jpg"));
        Image moelvenLogoTitle = new Image(new FileInputStream("src/main/resources/com.application/GUI/moelven_logo_title.jpg"));

        //Setting the image view
        ImageView imageViewM = new ImageView(moelvenLogoM);
        ImageView imageViewTitle = new ImageView(moelvenLogoTitle);

        imageViewM.setFitHeight(100);
        imageViewM.setPreserveRatio(true);

        imageViewTitle.setFitHeight(100);
        imageViewTitle.setPreserveRatio(true);

        Region region1 = new Region();
        HBox.setHgrow(region1, Priority.ALWAYS);

        Region region2 = new Region();
        HBox.setHgrow(region2, Priority.ALWAYS);

        return new HBox(imageViewM, region1, imageViewTitle, region2);
    }


    private LineChart<String,Number> createLineChart() {

        final CategoryAxis xAxis = new CategoryAxis();
        final NumberAxis yAxis = new NumberAxis();
        xAxis.setLabel("Month");
        final LineChart<String, Number> lineChart =
                new LineChart<String, Number>(xAxis, yAxis);

        lineChart.setTitle("Stock Monitoring, 2010");

        XYChart.Series series1 = new XYChart.Series();
        series1.setName("Portfolio 1");

        series1.getData().add(new XYChart.Data("Jan", 23));
        series1.getData().add(new XYChart.Data("Feb", 14));
        series1.getData().add(new XYChart.Data("Mar", 15));
        series1.getData().add(new XYChart.Data("Apr", 24));
        series1.getData().add(new XYChart.Data("May", 34));
        series1.getData().add(new XYChart.Data("Jun", 36));
        series1.getData().add(new XYChart.Data("Jul", 22));
        series1.getData().add(new XYChart.Data("Aug", 45));
        series1.getData().add(new XYChart.Data("Sep", 43));
        series1.getData().add(new XYChart.Data("Oct", 17));
        series1.getData().add(new XYChart.Data("Nov", 29));
        series1.getData().add(new XYChart.Data("Dec", 25));

        lineChart.getData().add(series1);
        return lineChart;
    }

}

